bundle.census: Bundle Census of Multiple Networks

bundle.censusR Documentation

Bundle Census of Multiple Networks

Description

A function to perform the bundle census in multiple networks.

Usage

bundle.census(x, loops = FALSE)

Arguments

x

An array representing multiple relations.

loops

(logical) Also include loops in the census?

Details

A bundle is a particular type of pattern made of relations at different levels that is binding a pair of nodes or actors, and this function calculates the number of occurrences for each bundle class pattern in a given multiple network in x. The different types of relations in the network are typically recorded in a three dimensional array of stacked matrices, and edge-list and pairwise-list of relations need to be transformed first into arrays with for example function transf.

Depending on the direction and occurrence of each possible tie, then it is possible to count with seven dyadic configuration classes in the census given in the output where fFunctions bundles and summaryBundles provide bundle class occurrences in the network with a more detailed information.

Value

A table with the number occurrences in the distinct bundle class patterns occuring in x:

  • BUNDLES Total number of bundles in x, excluding the Null pattern.

  • NULL Null

  • ASYMM Asymmetric

  • RECIP Reciprocal

  • T.ENTR Tie Entrainment

  • T.EXCH Tie Exchange

  • MIXED Mixed pattern

  • FULL Full

  • LOOP Loops (if TRUE)

References

Ostoic, J.A.R. “Dyadic Patterns in Multiple Networks,” Advances in Social Networks Analysis and Mining, International Conference on, 475-481. 2011.

See Also

bundles, summaryBundles, transf

Examples

# create two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
       c(3,3,2))>.8, 3 ) )

# compute the bundle census
bundle.census(arr)

multiplex documentation built on July 30, 2026, 5:13 p.m.