Classify bundle class patterns in a system of multiple relations.
bundles(x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE, sep)An object of “Rel.Bundles” class with the distinct bundle class patterns.
Asymmetric ties
Reciprocal ties
Tie Entrainment
Tie Exchange
Mixed
Full
Loops (if chosen)
An array representing multiple relations.
(logical) Also include loops pattern?
(logical) Simplify the strings of relations?
(logical) Should labels of the nodes be included in the output?
(logical) Collapse the distinct levels of relations in the network?
(optional) Separator for the pairwise relations.
A bundle is a particular type of pattern made of relations at different levels that is binding a pair of nodes or actors in a network of relationships. A bundle class is a dyadic configuration resulting from the mixture of the direction and the types of ties between the nodes or actors. There are in total seven dyadic configuration classes, which are null, asymmetric, reciprocal, tie entrainment, tie exchange, mixed, and the full bundle pattern. This function provides detailed information about the bundle class patterns in multiple networks as lists of pair relations among the nodes or actors, except for the “null” pattern.
In case that the nodes are not labeled, then an identification number will be assigned according to the location of the nodes in the array representation and as well when the lb2lb option is set to FALSE.
This function assumes that the network is directed, and self ties are also considered in the output.
Long string labels are simplified with smpl, whereas the collapse option blurs the levels in the strings.
The input array for this function is always dichotomized, and it is possible to obtain the total number of occurrences in each bundle class pattern with the bundle.census function.
Ostoic, J.A.R. “Dyadic Patterns in Multiple Networks,” Advances in Social Networks Analysis and Mining, International Conference on, 475-481. 2011.
bundle.census, summaryBundles, transf.
# create two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
c(3,3,2))>.8, 3 ) )
# look at bundle patterns
bundles(arr)
Run the code above in your browser using DataLab