decomp: Decomposition of a Semigroup Structure

decompR Documentation

Decomposition of a Semigroup Structure

Description

A function to perform the decomposition of a semigroup structure.

Usage

decomp(S, pr, type = c("mca", "pi", "at", "cc"), reduc, fac)

Arguments

S

A “Semigroup” class object.

pr

Either an object of a “Congruence” class or an object of a “Pi.rels” class.

type

Type of decomposition on S where the reduction is based on:

  • mca meet-complements of atoms in the “Pi.rels” class

  • pi \pi-relations in the “Pi.rels” class

  • at atoms

  • cc congruence classes.

reduc

(optional and logical) Should the returned list include the reduced structures?

fac

(optional) Factor subject to decomposition.

Details

The decomp function reduces an algebraic structure, such as a semigroup, to determine which class members in the system are congruent. The resulting object consists of congruent elements that belong to the lattice of congruence classes in the structure. If the input data comes from the Pacnet program, these elements take the form of \pi-relations or meet-complements of atoms; otherwise, they are equivalent elements that satisfy the substitution property.

A “Semigroup” class object may contain unavailable values in its multiplication table, typically when it is produced as an image by the fact function. In such cases, the semigroup can be reduced with the force option, which adds equations to the string relations to eliminate NA values in the semigroup data.

Use the reduc function to reduce the partial order table.

Value

A list object of “Decomp” class having:

clu

vector with class membership

eq

equations in decomposition

IM

(optional) image matrices

PO

(optional) partial order table

ord

(optional) vector with order of image matrices

References

Pattison, Philippa E. Algebraic Models for Social Networks. Cambridge University Press. 1993.
Hartmanis, J. and R.E. Stearns Algebraic Structure Theory of Sequential Machines. Prentice-Hall. 1966.

See Also

fact, cngr, reduc, pi.rels, semigroup, partial.order, green.rel.


multiplex documentation built on July 30, 2026, 5:13 p.m.