diagram.levels: Levels in Lattice Diagram

diagram.levelsR Documentation

Levels in Lattice Diagram

Description

A function to represent a textual interpretation of the levels in a given lattice diagram.

Usage

diagram.levels(x, perm = FALSE)

Arguments

x

A matrix representing partial order relations.

perm

optional and logical) Return automorphism of a permuted structure?

Details

This function provides a textual interpretation of the different levels in the lattice diagram of the partial order structure among actors and ties in the network.

When reducing a multiple network, the partial order structure may define different classes of elements based on their inclusion relations. The illustration produced by the diagram function typically shows these levels of ordered relations, which this routine then interprets.

Value

A named list with components of the “levels” in the concept diagram produced by diagram.

If perm is specified, the function returns a data frame containing the elements of the partial order structure, with column names indicating the element classes. It also returns a vector of levels and a matrix of the permuted structure.

Note

This function requires that the Rgraphviz package is installed. Since function grDevices::pictex() inside this routine is for historical interest only since R 4.4.0, the warning message has been suppressed before its future replacement.

See Also

partial.order, diagram, perm

Examples

# load the data
data("incubA")

# given e.g. a partial order table in the object 'po'
po <- incubA |> getElement("IM") |> 
  as.strings() |> 
  partial.order(type="strings")

# find the levels in the lattice diagram
## Not run: 
diagram.levels(po)

## End(Not run)

multiplex documentation built on July 30, 2026, 5:13 p.m.