edgeT: Edge Table Generator

edgeTR Documentation

Edge Table Generator

Description

Produce the Edge Table of multiple relations.

Usage

edgeT(x, semigroupClass)

Arguments

x

An array, usually with three dimensions of stacked matrices where the multiple relations are placed.

semigroupClass

(optional and logical) Return a “Semigroup” class object?

Details

Function edgeT is to produce the Edge Table of multiple relations in a network, which is a complete right multiplication table of the semigroup having its elements for each of its generators,

Value

A list of “EdgeTable” class object.

gens

generator relations

ET

Edge Table

References

Cannon, J.J. “Computing the ideal structure of finite semigroup,” Numerische Mathematik, 18, 254-266. 1971.
Pattison, P.E. Algebraic Models for Social Networks. Cambridge University Press. 1993.

See Also

wordT, semigroup.

Examples

# create two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
       c(3,3,2))>.5, 1 ) )

# obtain its edge table
edgeT(arr)

multiplex documentation built on July 30, 2026, 5:13 p.m.