expos: Network Exposure for Multiple Networks

exposR Documentation

Network Exposure for Multiple Networks

Description

Function to measure the network exposure of the nodes according to a chosen relational system representing the multiple network.

Usage

expos(rs, classes = FALSE, allClasses = FALSE, allNodes = TRUE)

Arguments

rs

An object of “Rel.System”, typically with node attributes.

classes

(optional and logical) Should categories of adopters be included in the output?

allClasses

(optional and logical, only for classes) Include empty classes within the categories of adopters?

allNodes

(optional and logical, only for classes) Include all actors in the network regardless they are in the chosen system?

Details

This function generalises the measure of network exposure for multiple networks based on the characteristics of the selected relational system. Such a system may represent the entire network or a configuration of strong or weak ties among the actors. It is also possible to specify different behaviours of the nodes representing social actors, expressed through the relational system. The network exposure measure is calculated on the basis of the immediate neighbours of the reference actor.

Value

Classes

when classes is set to TRUE, the adoption membership for the type of relational system chosen, including isolated actors in the system

Bonds

type of bonds of the relational system (cf. rel.sys)

Exposure

the exposure to the attribute(s) for acquisition through immediate neighbour relations

References

Ostoic, J.A.R. “Creating context for social influence processes in multiplex networks.” Network Science, 5(1), 1-29.
Valente, T. W. Social networks and health. Oxford University Press. 2010.
Rogers, E. The Diffusion of Innovations. 5th ed. (1st ed. 1964) The Free Press. 2003.

See Also

rel.sys, neighb, bundles

Examples

# create two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
       c(3,3,2))>.5, 1 ) )

# compute the exposure measure first array in 'arr' is for attributes with adopter categories
arr |> 
  rel.sys(att = 1) |> 
  expos(classes = TRUE)

multiplex documentation built on July 30, 2026, 5:13 p.m.