green.rel: Green's Relations of Abstract Semigroups

green.relR Documentation

Green's Relations of Abstract Semigroups

Description

A function to produce the Green's relations of a semigroup object.

Usage

green.rel(x)

Arguments

x

A “Semigroup” class object.

Details

Function green.rel produces the egg-box diagram (Green, 1951) of an abstract semigroup S, which is the union of the left compatible R equivalence and the right compatible L equivalence classes that makes the D-class on S. Notice that some systems have the D-class equal to S.

Value

A list object of “Green.Rels” and “Semigroup” class having:

S

multiplication matrix of the abstract semigroup

gens

generator relations of S

dim

dimension of semigroup generators

ord

order of S

st

unique string relations

clu

list of vectors with clustering information of equivalence classes R and L

R

R equivalence classes

L

L equivalence classes

D

D equivalence classes

References

Green, J. “On the structure of semigroups,” Annals of Mathematics 54(1), 163–172, 1951.
Ostoic, JAR “Relational systems of transport network and provinces in ancient Rome,” in Mathematics for social sciences and arts – algebraic modeling. Springer Nature. 2023.

See Also

semigroup, diagram, as.semigroup, edgeT, wordT, fact, cngr, decomp

Examples

# create two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
       c(3,3,2))>.5, 1 ) )
# optional string labels
dimnames(arr)[[3]] <- list("n", "m")

# look at the Green's relations of its semigroup
semigroup(arr) |> 
  green.rel()

multiplex documentation built on July 30, 2026, 5:13 p.m.