hierar: Person and Relation Hierarchy

hierarR Documentation

Person and Relation Hierarchy

Description

Function to establish either the Person or the Relation Hierarchy in a multiple network.

Usage

hierar(W, x, type = c("person", "relation"))

Arguments

W

An object of the “Rel.Box” class.

x

( or character) Actor of reference, either by the label or by an integer with its location in array w (cf. rbox).

type

Type of hierarchy with respect to network in “w”:

  • person for Person Hierarchy.

  • relation for Relation Hierarchy.

Details

The set of row inclusions in the Relation Plane of a Relation-Box W defines a partial order: the ego's Relation Hierarchy. Similarly, the ego's or person's inclusions define another partial order: the ego's Person Hierarchy. In other words, the Person Hierarchy captures inclusion relations among actors, whereas the Relation Hierarchy captures inclusion relations among ties. Both hierarchies are defined from the perspective of a selected reference actor in the network.

Notice that the Relation Plane is an outcome from rbox, whereas the cumulative person hierarchy is obtained through the cph function.

Value

A list with an array that represents the partial order structure either of the Person Hierarchy in ph or of the Relation Hierarchy in rh. Both include the reference ego in pers.

References

Breiger, R.L. and P.E. Pattison, “Cumulated social roles: The duality of persons and their algebras,” Social Networks, 8, 215-256. 1986.

See Also

rbox, cph, partial.order, diagram

Examples

# create two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
       c(3,3,2))>.5, 1 ) )

# compute person hierarchy of a random actor from relation box
arr |> 
  rbox(k=1) |> 
  hierar(ceiling(runif(1, min=0, max=dim(arr)[2])), type="person")

multiplex documentation built on July 30, 2026, 5:13 p.m.