partial.order: Partial Order of String Relations or of Galois Derivations

partial.orderR Documentation

Partial Order of String Relations or of Galois Derivations

Description

Construct the partial order table of unique relations of the semigroup, or else of the concepts produced by Galois derivations.

Usage

partial.order(x, type = c("strings", "galois", "pi.rels"), lbs, sel, po.incl, valued)

Arguments

x

A ‘Strings’ or a ‘Galois’ class object.

type

Type of partial order:

  • strings for string relations

  • galois for Galois derivations

  • pi.rels for \pi-relations

lbs

(optional) Labels of the unique relations.

sel

(optional) Selected elements in x for the partial order.

po.incl

(optional, only for pi.rels) Include the partial order in the \pi-relations?

valued

(optional and logical) Treat string relations in x as valued?

Details

To get the partial order of an entire semigroup, both generators and compound relations must be considered. This information and the labels of the unique relations are given by the strings function. cf. semigroup to see how the x should be specified properly.

Galois derivations are now possible to be partially ordered as well, and this option is based on the output given by the galois function.

Value

An object of ‘Partial.Order’ class with the partial order table in a matrix format.

References

Pattison, P.E. Algebraic Models for Social Networks. Cambridge University Press. 1993.
Ganter, B. and R. Wille Formal Concept Analysis – Mathematical Foundations. Springer. 1996.

See Also

as.strings, strings, galois, perm, diagram, fltr.

Examples

# load a dataset 
data("incubA")

# strings in structure and partial order
strings(incubA$IM) |> 
  partial.order()

multiplex documentation built on July 30, 2026, 5:13 p.m.