pi.rels: pi-Relations

pi.relsR Documentation

\pi-Relations

Description

A function to produce the \pi-relations of a partially ordered structure.

Usage

pi.rels(x, po.incl, vc, po)

Arguments

x

An object of a “Ind.incl” or “Pacnet” class.

po.incl

(optional and logical) Include partial order in outcome?

vc

(optional) Vector with induced inclusions to compute.

po

(optional) Matrix with partial order associated to induced inclusions.

Details

The totality of \pi-relations are represented with an array format, and the arrangement of meet-complements in this array are congruences that serve for the decomposition of a partially ordered semigroup structure.

Induced inclusions to the partial order in x as a “Ind.incl” class object are produced by the fact function, while induced inclusions as a “Pacnet” class object comes from the outcome of a Pacnet log-report. With either case, \pi-relations are derived from the induced inclusions in a factorization process of a partially ordered semigroup.

A visualization of the \pi-relations partial order arrangement with function diagram is feasible provided that the resulted “Pi.rels” class object computes a “Pi.rels” class with the type option "pi.rels" in function partial.order. In such case, including the partial order with po.incl and a addition in po is a good idea since the partial order is the minimal element of the lattice of congruence relations.

Producing the partial order structure of a set of \pi-relations can be resource consuming and for exploring and other purposes, with vc option one can limit the amount of induced inclusions to compute.

Value

An object of the “Pi.rels” class with:

pi

\pi-relations, eventually with partial order

at

atoms

mca

meet-complements of atoms

po

partial order (if included)

References

Pattison, Philippa E. Algebraic Models for Social Networks. Cambridge University Press. 1993.

See Also

fact, decomp, partial.order, diagram, semigroup, pacnet


multiplex documentation built on July 30, 2026, 5:13 p.m.