read.dl: Read 'dl' Files

read.dlR Documentation

Read dl Files

Description

A function to read files with the Ucinet dl format.

Usage

read.dl(file)

Arguments

file

Character vector containing a file name or path of the data representing the network.

Details

Ucinet dl format is to represent multiple and two-mode network structures. It is used in NetDraw, which is a component of the Ucinet program. Besides multiple networks, this function can read two-mode structures as well but the ‘EDGELIST’ option in DL is not yet supported for reading.

Value

A data frame for two-mode networks, or an array representing the multiple networks with one set of actors.

References

Borgatti, S.P., NetDraw Software for Network Visualization. Analytic Technologies. 2002.
Borgatti, S.P., Everett, M.G. and Freeman, L.C. Ucinet for Windows: Software for Social Network Analysis. Analytic Technologies. 2002.

See Also

write.dl, edgel, read.gml


multiplex documentation built on July 30, 2026, 5:13 p.m.