read.gml: Read 'gml' Files

read.gmlR Documentation

Read gml Files

Description

A function to read files with the gml format.

Usage

read.gml(file, as = c("edgel", "array"), directed = TRUE, coords = FALSE)

Arguments

file

Character vector containing a file name or path of the data representing the network.

as

Data format for output:

  • edgel Edge list with send/receive/ties format

  • array Two- or three-dimensional array

directed

(logical) Is the graph directed?

coords

(optional and logical) Include coordenates in gml file?

Details

The gml format, an acronym for graph modelling language, provides capabilities to represent multiple networks and add arguments both to the nodes and the edges for visualization purposes.

For the multiplexity in the ties the gml file distinguishes “graphics” arguments inside “edge”. Both “style” and “fill” are supported here and the former has priority over the latter in case the two are given; otherwise when these arguments are absent, the function separates up to a couple of relational levels when several pairwise ties are specified.

Node attributes can be retrieved as well when coordinates in coords are chosen.

Value

Depending the option chosen, the output is either a data frame or an array representing the multigraph. If the coordenates are chosen then these are part of the obejct structure, but they are not visible.

References

visone: Software for the analysis and visualization of social networks. http://visone.info

See Also

write.gml, edgel, read.dl


multiplex documentation built on July 30, 2026, 5:13 p.m.