rel.sys: Relational System of Network

rel.sysR Documentation

Relational System of Network

Description

Function to create a Relational System of a multiple network.

Usage

rel.sys(x, type = c("tolist", "toarray"), bonds = c("entire", "strong", "weak", 
        "asym", "recp", "txch", "tent", "mixd", "full"), loops = FALSE, 
        sel = NULL, att = NULL, sep)

Arguments

x

Array with three dimensions of stacked matrices with generating relations.

type

Is the transformation about:

  • tolist (Array of) matrices into lists of pairwise relations.

  • toarray Lists of pairwise relations into (array of) matrices.

bonds

the type of bonds to be used in the creation of the relational system

  • entire The “entire” network (default, same as full)

  • strong Strong bonds

  • weak Weak bonds

  • asym Asymmetric ties

  • recp Reciprocal ties

  • txch Tie exchange bundles

  • tent Tie entrainment bundles

  • mixd Mixed bundles

  • full Whole network (same as entire)

loops

(optional and logical) Include loops in relational system.

sel

(optional) Vector with set of actors to select.

att

(optional) Arrays in x corresponding to attributes.

sep

(optional) Pair separator for pairwise relations.

Details

A relational system of network x is a configuration with a particular pattern like the bond type among members. For instance, when the type of bonds chosen is entire then the nodes with ties are considered in the relational system without isolated nodes. Besides, strong bonds are relational bundles with a mutual character, whereas weak bonds are those patterns exclusively without mutual character.

It is also possible to select the network members having or *not* having the attribute that is specified in the Attrs output by using in argument sel. This is possible when choosing from a list with actor attributes.

Value

For type = "tolist" (default) option, an object of ‘Rel.System’ class where items are:

ord

order of network relational system

nodes

nodes in relational system

sel

selected set of actors

sys.ord

order of relational system with chosen bond type

incl

nodes included relational system with chosen bond type

excl

nodes excluded relational system with chosen bond type

bond.type

type of bonds used in relational system creation

size

number of ties in relational system

Note

(if needed) a note

sep

pairwise separator of relational system

Ties

ties in relational system

Attrs.ord

if att is not NULL, number of nodes with chosen attribute(s)

Attrs

if att is not NULL, actors with chosen attribute(s)

For type = "toarray", the output is a two or three dimensional dichotomous array recording the relations among the actors in the network.

References

Ostoic, J.A.R. “Creating context for social influence processes in multiplex networks.” Network Science, 5(1), 1-29.

See Also

expos, bundles, neighb

Examples

# create two binary relations among three elements
arr <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
       c(3, 3, 2) ) > .9, 3 ) )

# establish system of strong bonds
arr |> rel.sys(bonds = "strong")

# first array is for attributes
arr |> rel.sys(att = 1)

# select first node
arr |> rel.sys(sel = 1)

multiplex documentation built on July 30, 2026, 5:13 p.m.