signed: Signed Network

signedR Documentation

Signed Network

Description

Construct the signed network of a system made of contrasting relations.

Usage

signed(P, N = NULL, lbs)

Arguments

P

Array with positive ties and eventually with negative ties (see ‘details’).

N

(optional) Array with the negative ties.

lbs

(optional) Labels for returned signed matrix.

Details

This function coerces an array(s) to become a ‘Signed’ object. Positive ties are always in the first argument, and in case that this array has three dimensions, the second dimension is considered as the negative ties, provided that N is still NULL.

If ambivalent ties are present in the structure then the signed matrix represent positive, negative, ambivalent, and null ties as p, n, a, and o respectively; otherwise, the values are 1, -1, and 0.

Value

A ‘Signed’ class object with items:

val

Valences in s

s

Signed matrix

A warning message is shown when the N argument has more than two dimensions.

References

Doreian, P., V. Batagelj and A. Ferligoj Generalized Blockmodeling. Cambridge University Press. 2004.

See Also

semiring, as.signed

Examples

# load a dataset
data("incubA")

# make signed matrix of image matrix in dataset
incubA |> getElement("IM") |> signed()

multiplex documentation built on July 30, 2026, 5:13 p.m.