strings: Strings of Relations

stringsR Documentation

Strings of Relations

Description

Function to obtain labels of unique relations, and generators and compound relations of a complete semigroup structure.

Usage

strings(x, equat = FALSE, k = 2, smpl, valued)

Arguments

x

Array with three dimensions of stacked matrices with generating relations.

equat

(logical) Include equations in output?

k

Length of strings in equations.

smpl

(optional and logical) Simplify string relations for output?

valued

(optional and logical) Valued format in strings?

Details

The strings are the unique relations, which constitute the elements of the complete semigroup. These are both the generators and the compound relations after applying the Axiom of Quality, which means that even some generators can be disregarded.

This function is especially useful to construct the partial order of relations and to establish the set of equations in the relational structure.

The maximum length of the strings in the equations is currently 4.

Value

An object of ‘Strings’ class.

wt

Generators and compound relations

ord

Order of structure

st

Labels of unique relations

equat

Equations among strings relations

References

Boorman, S.A. and H.C. White, “Social Structure from Multiple Networks. II. Role Structures.” American Journal of Sociology, 81 (6), 1384-1446. 1976.

See Also

partial.order, semigroup.

Examples

# create two binary relations among three elements
arr <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
       c(3, 3, 2) ) > .9, 3 ) )

# get string relations
strings(arr)

multiplex documentation built on July 30, 2026, 5:13 p.m.