summaryBundles: Summary of Bundle Classes

summaryBundlesR Documentation

Summary of Bundle Classes

Description

Function for pretty printing of bundle class patterns results.

Usage

summaryBundles(x, file = NULL, latex = FALSE, byties)

Arguments

x

A ‘Rel.Bundles’ class object.

file

(optional) Path where to place output file.

latex

(optional and logical) Latex format for output?

byties

(optional and logical) Expand tie patterns and collapse tie labels?

Details

This function prints the bundle census patterns existing in the network with an option to export such information in a friendly format. The dyadic bundle patterns are provided by the function bundles; however, the outcome of this function provides a list of pair lists for each bundle with the involved types of relations and nodes in the network. This form for presentation, although is convenient for further computation, it is not always easy to read for the human eye. The pair separator used to print the bundle occurrences is taken from the output of the bundles function.

If latex is set to TRUE, then the path file is activated to obtain a tex file with the different bundle class patterns. Finally, the optional argument byties provide more precise information about the patterned ties disregarding the relational content.

Value

The distinct bundle class patterns with a user friendly format.

Warning

Files with identical path and name to file will be overwritten.

References

Ostoic, J. A. R. “Dyadic Patterns in Multiple Networks,” Advances in Social Networks Analysis and Mining, International Conference on, 475-481. 2011.

See Also

bundles, bundle.census

Examples

# create two binary relations among three elements
arr <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
       c(3, 3, 2) ) > .9, 3 ) )

# print different relational bundles in 'arr'
arr |> 
  bundles() |> 
  summaryBundles()

multiplex documentation built on July 30, 2026, 5:13 p.m.