write.dat: Write 'dat' Files

write.datR Documentation

Write dat Files

Description

A function to write dat files.

Usage

write.dat(x, path)

Arguments

x

Array representing a multiple network structure.

path

Path with filename for output.

Details

dat” files are the format used in the Pacnet program inside StOCNET. In case that the input data represents a multiple network then a separate file will be produced, each file representing a single type of relationship in the system. The name of the output files depends on the object title.

Value

File(s) output with adjacency matrices with a .dat format.

In case that a directory in path for output does not exist then the folder is created.

References

StOCNET An open software system for the advanced statistical analysis of social networks.

See Also

pacnet, write.gml, write.dl


multiplex documentation built on July 30, 2026, 5:13 p.m.