write.dl: Write 'dl' Format Files

write.dlR Documentation

Write dl Format Files

Description

A function to write dl files representing multiple networks.

Usage

write.dl(x, file = NULL, type = c("nodelist", "fullmat"))

Arguments

x

Array or object representing a multiple network structure.

file

Path with filename for output.

type

Write data format type:

  • nodelist for node-list format

  • fullmat for fullmat format

Details

Files with dl format serve to represent multiple networks, and it is one used in NetDraw, which is a component of the Ucinet program.

Value

A file in path with the data with a .dl format.

References

Borgatti, S.P., NetDraw Software for Network Visualization. Analytic Technologies. 2002.
Borgatti, S.P., Everett, M.G. and Freeman, L.C. Ucinet for Windows: Software for Social Network Analysis. Analytic Technologies. 2002.

See Also

read.dl, write.gml, write.edgel, write.dat


multiplex documentation built on July 30, 2026, 5:13 p.m.