write.edgel: Write edge-list files

write.edgelR Documentation

Write edge-list files

Description

A function to write edge-list files having columns for sender, receiver, and ties in multiplex networks.

Usage

write.edgel(x, file = NULL, sep = "\t", header = TRUE)

Arguments

x

Array or object representing a multiple network structure.

file

(optional) Path with filename for output.

sep

(optional, default tabular) Separator between columns.

header

(logical) Include header in edge-list file?

Details

Write edge-list files with a send, receive, and ties, which is a data frame with at least two columns for the sender and receiver, and the different types of tie for multiplex networks, one column for each type of relation.

Value

A data frame having an edge-list format in a file with path or an object.

See Also

edgel, , write.dl


multiplex documentation built on July 30, 2026, 5:13 p.m.