write.gml: Write 'gml' Files

write.gmlR Documentation

Write gml Files

Description

A function to write files with a graph modelling language (gml) format.

Usage

write.gml(x, file = NULL)

Arguments

x

Array or object representing a multiple network structure.

file

(optional) Path with filename for output.

Details

The gml format, an acronym for graph modelling language, provides capabilities to represent multiple networks and add arguments to both the nodes and the edges for visualization purposes.

Value

A graph with modelling language format in a file with path or an object.

Warning

Files with identical path and name to file will be overwritten.

See Also

read.gml, write.dl, write.dat


multiplex documentation built on July 30, 2026, 5:13 p.m.