zbind: Bind Matrices and Multidimensional Arrays

zbindR Documentation

Bind Matrices and Multidimensional Arrays

Description

A function to combine or bind matrices and multidimensional arrays.

Usage

zbind(..., sort, force)

Arguments

...

One or more arrays having two or three dimensions.

sort

(optional and logical) Sort array in output according to labels?

force

(optional and logical) Force binding arrays with different dimensions?

Details

Function zbind is for stacking for instance two-dimensional arrays into a single three-dimensional object to represent a multivariate system structure. Both square and rectangular arrays are supported provided that the dimensions in the input are equal, and data frames should be transformed into arrays for the binding.

The dimnames in the array output correspond to the names of the first array in the input, and a warning message is given when the dimnames are NULL.

Argument force must be set to TRUE for matrices and arrays with different dimensions, and a message is given.

Value

Mostly a three dimensional array.

Warning

Arrays without dimnames are not fully supported.

See Also

mnplx, dichot, strings

Examples

# create two sets with two binary relations among three elements
arr1 <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
        c(3, 3, 2) ) > .9, 3 ) )

arr2 <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
        c(3, 3, 2) ) > .5, 3 ) )

# bind sets of data
zbind(arr1, arr2)

multiplex documentation built on July 30, 2026, 5:13 p.m.