| as.signed | R Documentation |
A generic function for coercing a matrix into a “Signed” class object.
as.signed(x, lbs)
x |
A matrix representing the signed network. |
lbs |
(optional) Labels for the signed matrix. |
Use this function to convert an array representing a signed network into an R object of
class “Signed”, as required by function semiring.
The array in x itself can be also a “Semiring” class object represented as
‘Rel.Q’ attribute for the semiring relational structure.
The input array in x as a “Signed” class.
signed, semiring
# load a network dataset
data("incubA")
# coerce parts of the signed matrix with two types of relations
signed(incubA$IM)$s[1:2,1:2] |>
as.signed()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.