powered by
A generic function for coercing a matrix into a “Signed” class object.
Signed
as.signed(x, lbs)
The input array in x as a “Signed” class.
x
A matrix representing the signed network.
(optional) Labels for the signed matrix.
Use this function to convert an array representing a signed network into an R object of class “Signed”, as required by function semiring.
semiring
The array in x itself can be also a “Semiring” class object represented as ‘Rel.Q’ attribute for the semiring relational structure.
Semiring
Rel.Q
signed, semiring
signed
# load a network dataset data("incubA") # coerce parts of the signed matrix with two types of relations signed(incubA$IM)$s[1:2,1:2] |> as.signed()
Run the code above in your browser using DataLab