| cngr | R Documentation |
Find the congruence relations of a given abstract semigroup or a partially ordered semigroup.
cngr(S, PO, uniq)
S |
A “ |
PO |
(optional) A partial order table. |
uniq |
(optional and logical) Return unique congruence relations? |
Congruencies are equivalence relations that preserve the operation between the correspondent classes in the algebraic structure where the different congruence classes are based on the substitution property of the semigroup object.
In case that the partial order is supplied in PO the computation of the congruence classes is slightly faster than for an abstract semigroup.
A “Congruence” class list object with:
S |
Semigroup of relations |
PO |
Partial order table (if specified) |
clu |
Congruence classes |
Hartmanis, J. and R.E. Stearns Algebraic Structure Theory of Sequential Machines. Prentice-Hall. 1966.
decomp, fact, pacnet
# create two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
c(3,3,2))>.5, 1 ) )
# abstract semigroup of 'arr'
S <- arr |> semigroup()
# look at the congruences in S
cngr(S)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.