Learn R Programming

multiplex (version 4.0)

comps: Find Components in Multiple Networks

Description

Function to find different components and isolated nodes in the multiple networks.

Usage

comps(x, bonds = c("entire", "strong", "weak"), sort)

Value

A list object of length two with the bonds type in the class attribute:

com

List or vector with network components

isol

Vector with network isolates

Arguments

x

An array representing a given network.

bonds

Type of bonds for components creation:

  • "entire": all bundle patterns

  • "strong": mutual bundles (reciprocal, exchange, and mixed)

  • "weak": asymmetrical bundles (and entraiment)

sort

(optional and logical, default FALSE) Sort components by size?

Details

Components and isolates in network x are derived from the transitive closure of bundle ties. By default, the computation takes the entire system, but the bonds option lets the selection of other types of relational bundles for the resulted components.

The sort argument outputs components length in ascending size, such as dyads, triads, and larger groups when present. Changing the order of the existing components may have consequences in the layout of the graph when plotting it with function multigraph.

See Also

bundles, summaryBundles, bundle.census, rel.sys

Examples

Run this code
# create two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
       c(3,3,2))>.5, 1 ) )

# find the components and isolates
comps(arr)

Run the code above in your browser using DataLab