| cph | R Documentation |
A function to calculate the Cumulated Person Hierarchy in networks of multiple relations.
cph(W, lbs)
W |
An object of the “ |
lbs |
(optional) Labels of the relational system. |
Uses the cumulated person hierarchy to determine partial structural equivalence among actors in a multiple network.
Two nodes are considered partially structurally equivalent only if they have identical role sets.
Output is determined by the properties of the Relation-Box product of function rbox, and
in case that the length of the labels differs from the order of the relational system, then labels will be ignored.
An object of “Partial.Order” class with an array representing the cumulated person hierarchy.
Breiger, R.L. and P.E. Pattison, “Cumulated social roles: The duality of persons and their algebras,” Social Networks, 8, 215-256. 1986.
Mandel, M.J. “Roles and networks: A local approach.” B.A. Honours thesis, Harvard University. 1978.
rbox, semigroup, diagram
# load a dataset
data("incubA")
# construct the Relation Box of the dataset image matrices and
# compute its cumulated person hierarchy
incubA |> getElement("IM") |>
rbox() |> cph()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.