| cscl | R Documentation |
A function to interpret a given many-valued formal context through a chosen scaling process.
cscl(x, cl, scale = c("nominal", "ordinal", "intord", "biord", "dichot"), sep)
x |
A table or array representing a many-valued formal context. |
cl |
A vector with the ordered conceptual scaling-levels in |
scale |
Type of scaling in the interpretation of
|
sep |
(optional, default dot) Pair separator among attributes and levels. |
Conceptual scaling is a special form of formal context in which each attribute of a many-valued context is interpreted through a scaling procedure. More broadly, it converts many-valued data into dichotomous data, producing a derived context according to the selected type of scaling. Conceptual scaling is therefore an interpretive method where both the choice of scale and the transformation of values are form part of the analysis, rather than following from a mathematically determined procedure.
The formal context represented in x must be associated to its conceptual scaling-levels recorded in cl as an ordered vector with all levels,
and a type of scaling derives the context into a dichotomous data frame with attribute ordinal values.
Once the partial order of the Galois derivation among the objects and attributes of the formal concept has been established,
the resulting derived context with dichotomous data can be represented as a concept lattice.
A data frame with a “conceptual.scaling” class representing a derived many-valued formal context with respect to the conceptual scaling-levels in cl.
The ordered conceptual levels and the pair separator are given in the class attribute.
Ganter, B. and R. Wille Formal Concept Analysis – Mathematical Foundations. Springer. 1996.
galois, partial.order, diagram.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.