A function to perform the decomposition of a semigroup structure.
decomp(S, pr, type = c("mca", "pi", "at", "cc"), reduc, fac)A list object of “Decomp” class having:
vector with class membership
equations in decomposition
(optional) image matrices
(optional) partial order table
(optional) vector with order of image matrices
A “Semigroup” class object.
Either an object of a “Congruence” class or an object of a “Pi.rels” class.
Type of decomposition on S where the reduction is based on:
mca meet-complements of atoms in the “Pi.rels” class
pi \(\pi\)-relations in the “Pi.rels” class
at atoms
cc congruence classes.
(optional and logical) Should the returned list include the reduced structures?
(optional) Factor subject to decomposition.
The decomp function reduces an algebraic structure, such as a semigroup, to determine which class members in the system are congruent.
The resulting object consists of congruent elements that belong to the lattice of congruence classes in the structure.
If the input data comes from the Pacnet program, these elements take the form of \(\pi\)-relations or meet-complements of atoms;
otherwise, they are equivalent elements that satisfy the substitution property.
A “Semigroup” class object may contain unavailable values in its multiplication table, typically when it is produced as an image by the fact function.
In such cases, the semigroup can be reduced with the force option, which adds equations to the string relations to eliminate NA values in the semigroup data.
Use the reduc function to reduce the partial order table.
Pattison, Philippa E. Algebraic Models for Social Networks. Cambridge University Press. 1993.
Hartmanis, J. and R.E. Stearns Algebraic Structure Theory of Sequential Machines. Prentice-Hall. 1966.
fact, cngr, reduc, pi.rels,
semigroup, partial.order, green.rel.