| expos | R Documentation |
Function to measure the network exposure of the nodes according to a chosen relational system representing the multiple network.
expos(rs, classes = FALSE, allClasses = FALSE, allNodes = TRUE)
rs |
An object of “ |
classes |
(optional and logical) Should categories of adopters be included in the output? |
allClasses |
(optional and logical, only for |
allNodes |
(optional and logical, only for |
This function generalises the measure of network exposure for multiple networks based on the characteristics of the selected relational system. Such a system may represent the entire network or a configuration of strong or weak ties among the actors. It is also possible to specify different behaviours of the nodes representing social actors, expressed through the relational system. The network exposure measure is calculated on the basis of the immediate neighbours of the reference actor.
Classes |
when |
Bonds |
type of bonds of the relational system (cf. |
Exposure |
the exposure to the attribute(s) for acquisition through immediate neighbour relations |
Ostoic, J.A.R. “Creating context for social influence processes in multiplex networks.” Network Science, 5(1), 1-29.
Valente, T. W. Social networks and health. Oxford University Press. 2010.
Rogers, E. The Diffusion of Innovations. 5th ed. (1st ed. 1964) The Free Press. 2003.
rel.sys, neighb, bundles
# create two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
c(3,3,2))>.5, 1 ) )
# compute the exposure measure first array in 'arr' is for attributes with adopter categories
arr |>
rel.sys(att = 1) |>
expos(classes = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.