| fact | R Documentation |
A function to factorize partially ordered semigroup structures by induced inclusions.
fact(S, P, uniq = TRUE, fac, atoms, mca, atmc, patm, k)
S |
A “ |
P |
A “ |
uniq |
(logical) Should the factorization include unique induced inclusions? |
fac |
(optional) The ‘factor’ to be factorized for partially ordered structures. |
atoms |
(optional and logical) Short for including |
mca |
(optional and logical) Include pairs of meet-complements of pair of atoms in output? |
atmc |
(optional and logical) Include meet-complements of pair of atoms in output? |
patm |
(optional and logical) Include potential atoms in output? |
k |
(optional) Integer with length of induced inclusion. |
Factorization is a subdirect-representation-based decomposition technique for a partially ordered semigroup. This procedure decomposes the algebraic structure into simpler components, called factors, each of which is a semigroup factor representing a specific homomorphic image of the algebra.
For partially ordered semigroups, these factors are isotone homomorphic images corresponding to maximally independent
features of the original semigroup of relations.
The quotient semigroups and the reduced partial order tables together form the factorizing set, which
is given by the decomposition with decomp.
A list of “Ind.incl” class object having:
po |
partial order table |
iin |
list of induced inclusions pairwise listed |
niin |
length of induced inclusions |
patm |
(for |
atm |
vector with atoms |
atmc |
(for |
mc |
array of meet-complements of atoms |
Class attribute, and a warning message when no substitution property found in induced inclusions.
Ardu, S. ASNET – Algebraic and Statistical Network Analysis. User Manual. University of Melbourne. 1995. (for the implementation algorithm)
decomp, cngr, pacnet
# create a partially ordered semigroup
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
c(3,3,2))>.5, 1 ) )
# semigroup of relations
S <- semigroup(arr)
# string relations and partial order
P <- strings(arr) |>
partial.order()
# perform the factorisation of PO S
fact(S, P)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.