| galois | R Documentation |
Function to compute Galois derivations between partially ordered subsets.
galois(x, labeling = c("full", "reduced"), sep)
x |
An incidence matrix with objects and attributes. |
labeling |
Type of labeling for the Galois derivations:
|
sep |
(optional) Pair separator for the pairwise relations, default “comma-space”. |
A Galois derivation, or Galois connection, between the power sets of G and M is defined
for subsets A \subseteq G and B \subseteq M by the set of attributes common to all objects in A,
or A^\prime, and the set of objects having all attributes in B, or B^\prime.
An inclusion with the "full" labeling in the output implies first objects and then attributes in the
Galois connection, whereas with the "reduced" option the output assumes inclusions of attributes first and then the objects.
Notice that for many-valued formal contexts the structure is derived from a concept scaling through function cscl
where is possible to define a pair separator between attributes and their values. A warning message is produced when there is a
conflict between such separators and the pair separator chosen in sep for extents and intents.
A list of “Galois” class object with Galois derivations of objects and attributes as list labels:
sep |
pair separator |
gc |
galois connections of pairs |
Notice that the object attribute class only is printed for "full" labeling, which is an intrinsic
part of the outcome for a "reduced" labeling.
Ganter, B. and R. Wille Formal Concept Analysis – Mathematical Foundations. Springer. 1996.
partial.order, cscl, diagram, fltr.
# incidence matrix as a data frame
dfr <- data.frame(x=1:3, y=5:7)
# compute galois derivations
galois(dfr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.