A Galois derivation, or Galois connection, between the power sets of \(G\) and \(M\) is defined
for subsets \(A \subseteq G\) and \(B \subseteq M\) by the set of attributes common to all objects in \(A\),
or \(A^\prime\), and the set of objects having all attributes in \(B\), or \(B^\prime\).
An inclusion with the "full" labeling in the output implies first objects and then attributes in the
Galois connection, whereas with the "reduced" option the output assumes inclusions of attributes first and then the objects.
Notice that for many-valued formal contexts the structure is derived from a concept scaling through function cscl
where is possible to define a pair separator between attributes and their values. A warning message is produced when there is a
conflict between such separators and the pair separator chosen in sep for extents and intents.