| green.rel | R Documentation |
A function to produce the Green's relations of a semigroup object.
green.rel(x)
x |
A “ |
Function green.rel produces the egg-box diagram (Green, 1951) of an abstract semigroup S,
which is the union of the left compatible R equivalence and
the right compatible L equivalence classes that makes the D-class on S.
Notice that some systems have the D-class equal to S.
A list object of “Green.Rels” and “Semigroup” class having:
S |
multiplication matrix of the abstract semigroup |
gens |
generator relations of |
dim |
dimension of semigroup generators |
ord |
order of |
st |
unique string relations |
clu |
list of vectors with clustering information of equivalence classes |
R |
|
L |
|
D |
|
Green, J. “On the structure of semigroups,” Annals of Mathematics 54(1), 163–172, 1951.
Ostoic, JAR “Relational systems of transport network and provinces in ancient Rome,” in
Mathematics for social sciences and arts – algebraic modeling. Springer Nature. 2023.
semigroup, diagram, as.semigroup,
edgeT, wordT, fact, cngr, decomp
# create two binary relations among three elements
arr <- round( replace( array(runif(18), c(3,3,2)), array(runif(18),
c(3,3,2))>.5, 1 ) )
# optional string labels
dimnames(arr)[[3]] <- list("n", "m")
# look at the Green's relations of its semigroup
semigroup(arr) |>
green.rel()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.