mnplx: Make Multiple Networks as Monoplex Structures
Description
A function to transform multiple networks into a monoplex structure.
Usage
mnplx(net, directed = TRUE, valued, diag, clu)
Value
A matrix of monoplex relations.
Arguments
net
A three-dimensional array to be transformed into a matrix.
directed
(optional and logical) Make symmetric the matrix?
valued
(optional and logical) Dichotomize the matrix?
diag
(optional and logical) Include diagonals?
clu
(optional) Vector with a cluster for permutation.
Details
This function is to collapse multiple types of tie of a network net recorded in an array into a matrix representation with monoplex relations.
Other transformations on net are dichotomizing a valued network, and convert directed networks into undirected systems having or not self-relations
depending on the value of diag.
Moreover, the resulted matrix can be permuted with a clustering information in a vector in clu as with perm.