| pacnet | R Documentation |
A function to read output files and import from the Pacnet program with full factorization option.
pacnet(file, toarray = FALSE, uniq = FALSE, transp = FALSE, sep)
file |
Path with filename of Log-Report. |
toarray |
(logical) Transform induced inclusions into arrays? |
uniq |
(logical) Consider only unique induced inclusions? |
transp |
(logical) Transpose partial order tables? |
sep |
(optional) Pair separator in pairwise relations. |
This function is used to read the output file from the Pacnet program, which typically has the .out extension.
By default the result is given in a list format, but it is possible to transform the pair lists into arrays.
Note that the options in the Pacnet program should include the full factorization in the output; otherwise the object will be NULL.
Also note that only partial order structures of order 36 and less are currently supported.
A ‘Pacnet’ class object with items:
ii |
: Induced inclusions |
at |
: Atoms |
mc |
: Meet complements |
Pattison, P, S Wasserman, G Robins and AM Kanfer “Statistical Evaluation of Algebraic Constraints for Social Networks,” Journal of Mathematical Psychology, 44, 536-568. 2000
pi.rels, cngr, decomp, write.dat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.