| partial.order | R Documentation |
Construct the partial order table of unique relations of the semigroup, or else of the concepts produced by Galois derivations.
partial.order(x, type = c("strings", "galois", "pi.rels"), lbs, sel, po.incl, valued)
x |
A ‘ |
type |
Type of partial order:
|
lbs |
(optional) Labels of the unique relations. |
sel |
(optional) Selected elements in |
po.incl |
(optional, only for |
valued |
(optional and logical) Treat string relations in |
To get the partial order of an entire semigroup, both generators and compound relations must be considered.
This information and the labels of the unique relations are given by the strings function.
cf. semigroup to see how the x should be specified properly.
Galois derivations are now possible to be partially ordered as well, and this option is based on the
output given by the galois function.
An object of ‘Partial.Order’ class with the partial order table in a matrix format.
Pattison, P.E. Algebraic Models for Social Networks. Cambridge University Press. 1993.
Ganter, B. and R. Wille Formal Concept Analysis – Mathematical Foundations. Springer. 1996.
as.strings, strings, galois, perm, diagram, fltr.
# load a dataset
data("incubA")
# strings in structure and partial order
strings(incubA$IM) |>
partial.order()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.