powered by
Function to permutate a given array of relations.
perm(x, clu, rev, lbs, sort)
A permuted matrix or array
Matrix or array to permute.
Vector of cluster for permutation.
(optional and logical) Revert order in clu?
clu
(optional) Vector of labels after permutation.
(optional and logical) Sort array according to labels?
This function performs a permutation of a given array or matrix representing relations according to a clustering vector of membership.
cph, partial.order
cph
partial.order
# scan the multiplication table data s <- matrix(data=c(1, 1, 1, 3, 3, 3, 3, 3, 3), nrow=3, ncol=3, byrow=TRUE) # the permutation as an endomorphism perm(s, clu = c(1,2,3))
Run the code above in your browser using DataLab