pfvn: Pathfinder Valued Networks and Triangle Inequality
Description
A function to produce the skeleton of a valued network with the pathfinder algorithm and triangle inequality.
Usage
pfvn(x, r, q)
Value
max
\(\max\) value of the network with the Frobenius norm
r
parameter \(r\)
q
parameter \(q\)
Q
salient structure of x
Note
A note when triangle inequality is used
Arguments
x
Network data, typically a valued array.
r
Distance parameter.
q
Parameter with the minimum distance between actors in the proximity matrix.
Details
Pathfinder analysis is based on a symmetric adjacency matrix or array in x representing valued networks where
the values reflect the “proximity” between pairs of network members.
This function depends heavily on internal function cpath where the aim is to produce the skeleton or the salient structure of x.
The pathfinder structure is for undirected networks, whereas for directed network structures the triangle inequality principle is applied.
Parameter \(q\) represents the length of all walks computed over the semiring in the produced dissimilarity matrix,
while \(r\) is a distance measure computed by the Minkowski operation.
References
Schvaneveldt, R., Durso, F. and Dearholt, D., “Network structures in proximity data,” in G. Bower, ed., The Psychology of Learning and Motivation: Advances in Research & Theory, vol. 24, Academic Press, pp. 249-284. 1989.
Batagelj, V., Doreian, P., Ferligoj, A. and Kejzar, N., Understanding Large Temporal Networks and Spatial Networks: Exploration, Pattern Searching, Visualization and Network Evolution, Wiley. 2014.