| rbox | R Documentation |
Function to construct the Relation-Box of a multiple network.
rbox(w, transp = FALSE, smpl = FALSE, k = 3, tlbs)
w |
Array with three dimensions of stacked matrices with generating relations. |
transp |
(optional and logical) Include matrix transpose in |
smpl |
(optional and logical) Simplify strings of relations? |
k |
Length of Relation-Box (in |
tlbs |
(optional) Vector with labels for transpose relations. |
If transp = TRUE the labels of the transpose are toggle case of the labels of the original matrices, and in such case, it is advised to simplify the strings of relations.
To prevent a transposed structure for a certain array of w, use NA in the vector the transpose labels tlbs corresponding to the respective matrix.
Values of k until 9 are supported.
An object of the ‘Rel.Box’ class.
w |
Primitive relations in Relation-Box |
W |
Structure of Relation-Box |
lbs |
Labels in relational system |
Note |
(optional) Notes indicating the particularities in the input |
Orels |
Original labels of relations |
Srels |
(optional) Simplified labels of relations |
Trels |
(optional) Transposed relation labels |
k |
Maximal length of the word |
z |
Length of the Relation-Box in the |
May take a long time of computation with many types of relations and when the order of the multiplex network is high, and turning k to more than three.
Winship, C. and M.J. Mandel “Roles and positions: A critique and extension of the blockmodelling approach,” Sociological Methodology, 314-344. 1983.
cph, semigroup, hierar
# load the data
data("incubA")
# relation box of image matrices in dataset
## Not run:
incubA |> getElement("IM") |>
rbox()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.