| read.dl | R Documentation |
dl Files
A function to read files with the Ucinet dl format.
read.dl(file)
file |
Character vector containing a file name or path of the data representing the network. |
Ucinet dl format is to represent multiple and two-mode network structures.
It is used in NetDraw, which is a component of the Ucinet program.
Besides multiple networks, this function can read two-mode structures as well but
the ‘EDGELIST’ option in DL is not yet supported for reading.
A data frame for two-mode networks, or an array representing the multiple networks with one set of actors.
Borgatti, S.P., NetDraw Software for Network Visualization. Analytic Technologies. 2002.
Borgatti, S.P., Everett, M.G. and Freeman, L.C. Ucinet for Windows: Software for Social Network Analysis. Analytic Technologies. 2002.
write.dl, edgel, read.gml
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.