| read.gml | R Documentation |
gml Files
A function to read files with the gml format.
read.gml(file, as = c("edgel", "array"), directed = TRUE, coords = FALSE)
file |
Character vector containing a file name or path of the data representing the network. |
as |
Data format for output:
|
directed |
(logical) Is the graph directed? |
coords |
(optional and logical) Include coordenates in |
The gml format, an acronym for graph modelling language, provides capabilities to represent multiple networks and
add arguments both to the nodes and the edges for visualization purposes.
For the multiplexity in the ties the gml file distinguishes “graphics” arguments inside “edge”.
Both “style” and “fill” are supported here and the former has priority over the latter in case the two are given;
otherwise when these arguments are absent, the function separates up to a couple of relational levels when several pairwise ties are specified.
Node attributes can be retrieved as well when coordinates in coords are chosen.
Depending the option chosen, the output is either a data frame or an array representing the multigraph. If the coordenates are chosen then these are part of the obejct structure, but they are not visible.
visone: Software for the analysis and visualization of social networks. http://visone.info
write.gml, edgel, read.dl
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.