| rel.sys | R Documentation |
Function to create a Relational System of a multiple network.
rel.sys(x, type = c("tolist", "toarray"), bonds = c("entire", "strong", "weak",
"asym", "recp", "txch", "tent", "mixd", "full"), loops = FALSE,
sel = NULL, att = NULL, sep)
x |
Array with three dimensions of stacked matrices with generating relations. |
type |
Is the transformation about:
|
bonds |
the type of bonds to be used in the creation of the relational system
|
loops |
(optional and logical) Include loops in relational system. |
sel |
(optional) Vector with set of actors to select. |
att |
(optional) Arrays in |
sep |
(optional) Pair separator for pairwise relations. |
A relational system of network x is a configuration with a particular pattern like the bond type among members.
For instance, when the type of bonds chosen is entire then the nodes with ties are considered in the relational system without isolated nodes.
Besides, strong bonds are relational bundles with a mutual character, whereas weak bonds are those patterns exclusively without mutual character.
It is also possible to select the network members having or *not* having the attribute that is specified in the Attrs output by using in argument sel.
This is possible when choosing from a list with actor attributes.
For type = "tolist" (default) option, an object of ‘Rel.System’ class
where items are:
ord |
order of network relational system |
nodes |
nodes in relational system |
sel |
selected set of actors |
sys.ord |
order of relational system with chosen bond type |
incl |
nodes included relational system with chosen bond type |
excl |
nodes excluded relational system with chosen bond type |
bond.type |
type of bonds used in relational system creation |
size |
number of ties in relational system |
Note |
(if needed) a note |
sep |
pairwise separator of relational system |
Ties |
ties in relational system |
Attrs.ord |
if |
Attrs |
if |
For type = "toarray", the output is a two or three dimensional dichotomous array recording the relations among the actors in the network.
Ostoic, J.A.R. “Creating context for social influence processes in multiplex networks.” Network Science, 5(1), 1-29.
expos, bundles, neighb
# create two binary relations among three elements
arr <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
c(3, 3, 2) ) > .9, 3 ) )
# establish system of strong bonds
arr |> rel.sys(bonds = "strong")
# first array is for attributes
arr |> rel.sys(att = 1)
# select first node
arr |> rel.sys(sel = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.