| rm.isol | R Documentation |
Function to remove isolate nodes in simple and multiple networks.
rm.isol(x, diag, diag.incl)
x |
Matrix or array representing a network. |
diag |
(optional and logical, for arrays) Include diagonals in transformation? |
diag.incl |
(optional and logical, for arrays) Include diagonals in output? |
Isolated nodes do not have any edges in the network, and in a multivariate system, there is no edges adjacent to these kinds of nodes at any level.
A matrix or an array representing a multiple network without the isolated actors.
edgel, zbind
# create two binary relations among three elements
arr <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
c(3, 3, 2) ) > .5, 3 ) )
# remove isolates (if exist)
rm.isol(arr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.