Learn R Programming

multiplex (version 4.0)

rm.isol: Remove Isolates from Network

Description

Function to remove isolate nodes in simple and multiple networks.

Usage

rm.isol(x, diag, diag.incl)

Value

A matrix or an array representing a multiple network without the isolated actors.

Arguments

x

Matrix or array representing a network.

diag

(optional and logical, for arrays) Include diagonals in transformation?

diag.incl

(optional and logical, for arrays) Include diagonals in output?

Details

Isolated nodes do not have any edges in the network, and in a multivariate system, there is no edges adjacent to these kinds of nodes at any level.

See Also

edgel, zbind

Examples

Run this code
# create two binary relations among three elements
arr <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
         c(3, 3, 2) ) > .5, 3 ) )

# remove isolates (if exist)
rm.isol(arr)

Run the code above in your browser using DataLab