| signed | R Documentation |
Construct the signed network of a system made of contrasting relations.
signed(P, N = NULL, lbs)
P |
Array with positive ties and eventually with negative ties (see ‘details’). |
N |
(optional) Array with the negative ties. |
lbs |
(optional) Labels for returned signed matrix. |
This function coerces an array(s) to become a ‘Signed’ object.
Positive ties are always in the first argument, and in case that this array has three dimensions,
the second dimension is considered as the negative ties, provided that N is still NULL.
If ambivalent ties are present in the structure then the signed matrix represent positive, negative, ambivalent, and null ties
as p, n, a, and o respectively; otherwise, the values are 1, -1, and 0.
A ‘Signed’ class object with items:
val |
Valences in |
s |
Signed matrix |
A warning message is shown when the N argument has more than two dimensions.
Doreian, P., V. Batagelj and A. Ferligoj Generalized Blockmodeling. Cambridge University Press. 2004.
semiring, as.signed
# load a dataset
data("incubA")
# make signed matrix of image matrix in dataset
incubA |> getElement("IM") |> signed()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.