Learn R Programming

multiplex (version 4.0)

wordT: Word Table of Relations

Description

Function to produce the Word Table of multiple relations as representation form of a semigroup of relations.

Usage

wordT(x)

Value

A ‘WordTable’ class object with items:

gens

Generator relations

WT

Word Table where “n” stands for node and “g” stands for generator

Arguments

x

Array with three dimensions of stacked matrices with generating relations.

Details

The Word Table is a consequence of the Edge Table (cf. edgeT) and the function gives a list of indexed elements in the complete semigroup.

In terms of the Cayley graph of the semigroup (cf. ccgraph, the collection of unique relations (both compound and generators) are represented by nodes. On the other hand, the generators are edges that record the result of post-multiplying the compound relations by the generators.

The labels for the elements can be retrieved by the strings function.

The generators do not have values in neither the “node” nor the “generator” of the Word table since they are not a product of any other element in the semigroup (cf. ‘details’ for the rest of the values).

References

Cannon, J.J. “Computing the ideal structure of finite semigroup,” Numerische Mathematik, 18, 254-266. 1971.
Pattison, P.E. Algebraic Models for Social Networks. Cambridge University Press. 1993.

See Also

edgeT, semigroup, strings, ccgraph

Examples

Run this code
# create two binary relations among three elements
arr <- round( replace( array( runif(18), c(3 ,3, 2) ), array( runif(18),
       c(3, 3, 2) ) > .9, 3 ) )

# obtain word table
wordT(arr)

Run the code above in your browser using DataLab