| write.dat | R Documentation |
dat Files
A function to write dat files.
write.dat(x, path)
x |
Array representing a multiple network structure. |
path |
Path with filename for output. |
“dat” files are the format used in the Pacnet program inside StOCNET.
In case that the input data represents a multiple network then a separate file will be produced,
each file representing a single type of relationship in the system.
The name of the output files depends on the object title.
File(s) output with adjacency matrices with a .dat format.
In case that a directory in path for output does not exist then the folder is created.
StOCNET An open software system for the advanced statistical analysis of social networks.
pacnet, write.gml, write.dl
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.