| write.dl | R Documentation |
dl Format Files
A function to write dl files representing multiple networks.
write.dl(x, file = NULL, type = c("nodelist", "fullmat"))
x |
Array or object representing a multiple network structure. |
file |
Path with filename for output. |
type |
Write data format type:
|
Files with dl format serve to represent multiple networks, and it is one used in NetDraw, which is a component of the Ucinet program.
A file in path with the data with a .dl format.
Borgatti, S.P., NetDraw Software for Network Visualization. Analytic Technologies. 2002.
Borgatti, S.P., Everett, M.G. and Freeman, L.C. Ucinet for Windows: Software for Social Network Analysis. Analytic Technologies. 2002.
read.dl, write.gml, write.edgel, write.dat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.