dl Format FilesA function to write dl files representing multiple networks.
write.dl(x, file = NULL, type = c("nodelist", "fullmat"))A file in path with the data with a .dl format.
Array or object representing a multiple network structure.
Path with filename for output.
Write data format type:
nodelist for node-list format
fullmat for fullmat format
Files with dl format serve to represent multiple networks, and it is one used in NetDraw, which is a component of the Ucinet program.
Borgatti, S.P., NetDraw Software for Network Visualization. Analytic Technologies. 2002.
Borgatti, S.P., Everett, M.G. and Freeman, L.C. Ucinet for Windows: Software for Social Network Analysis. Analytic Technologies. 2002.
read.dl, write.gml, write.edgel, write.dat