A function to write edge-list files having columns for sender, receiver, and ties in multiplex networks.
write.edgel(x, file = NULL, sep = "\t", header = TRUE)A data frame having an edge-list format in a file with path or an object.
Array or object representing a multiple network structure.
(optional) Path with filename for output.
(optional, default tabular) Separator between columns.
(logical) Include header in edge-list file?
Write edge-list files with a send, receive, and ties, which is a data frame with at least two columns for the sender and receiver, and the different types of tie for multiplex networks, one column for each type of relation.
edgel, , write.dl