| write.gml | R Documentation |
gml Files
A function to write files with a graph modelling language (gml) format.
write.gml(x, file = NULL)
x |
Array or object representing a multiple network structure. |
file |
(optional) Path with filename for output. |
The gml format, an acronym for graph modelling language, provides capabilities to represent multiple networks and add arguments to both the nodes and the edges for visualization purposes.
A graph with modelling language format in a file with path or an object.
Files with identical path and name to file will be overwritten.
read.gml, write.dl, write.dat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.