Learn R Programming

multiplex (version 4.0)

write.gml: Write gml Files

Description

A function to write files with a graph modelling language (gml) format.

Usage

write.gml(x, file = NULL)

Value

A graph with modelling language format in a file with path or an object.

Arguments

x

Array or object representing a multiple network structure.

file

(optional) Path with filename for output.

Warning

Files with identical path and name to file will be overwritten.

Details

The gml format, an acronym for graph modelling language, provides capabilities to represent multiple networks and add arguments to both the nodes and the edges for visualization purposes.

See Also

read.gml, write.dl, write.dat