gml FilesA function to write files with a graph modelling language (gml) format.
write.gml(x, file = NULL)A graph with modelling language format in a file with path or an object.
Array or object representing a multiple network structure.
(optional) Path with filename for output.
Files with identical path and name to file will be overwritten.
The gml format, an acronym for graph modelling language, provides capabilities to represent multiple networks and add arguments to both the nodes and the edges for visualization purposes.
read.gml, write.dl, write.dat